@@ -555,6 +555,7 @@ def _make_serverproxy_handler(name, command, environment, timeout, absolute_url,
             return {
                 'port': self.port,
                 'base_url': self.base_url,
+                '-': '-',
                 '--': '--'
             }
         @property
@@ -571,6 +572,12 @@ def _make_serverproxy_handler(name, command, environment, timeout, absolute_url,
                 return {self.settings['group']}
             return set()
 
+        @property
+        def allow_all(self):
+            if 'anyone' in self.settings:
+                return self.settings['anyone'] == '1'
+            return super().allow_all
+
         def _render_template(self, value):
             args = self.process_args
             if type(value) is str:
